declare name "DPSpecS (stereo)";
declare author "Alex Chechile";
declare version "The Ear Tone Toolbox v.1.01";
declare copyright "Copyright 2016 Alex Chechile (chechile@ccrma.stanford.edu)";
declare license "GNU GPL (see COPYING.txt)";
declare description "Generates a stereo spectrum of primary tones based on the f1 primary and the f0 QDT fundamental, which is also the spacing";

import("music.lib");
import("filter.lib");

f0 = hslider("f0",100,1,1150,0.0001); // f0 is the quadratic difference tone f2-f1 value
f1 = hslider("f1",1000,1,7000,0.0001); // f1 is the first primary tone

// primary tone spectrum
f2 = f0 + f1;
f3 = 2 * f0 + f1;
f4 = 3 * f0 + f1;
f5 = 4 * f0 + f1;
f6 = 5 * f0 + f1;
f7 = 6 * f0 + f1;
f8 = 7 * f0 + f1;
f9 = 8 * f0 + f1;
f10 = 9 * f0 + f1;
f11 = 10 * f0 + f1;
f12 = 11 * f0 + f1;

// optional sanity check
SC1 = osc(f2 - f1); // QDT
SC2 = osc(f3 - f1);
SC3 = osc(f4 - f1);
SC4 = osc(f5 - f1);

// Limit for f2/f1 ratio to stay between 1.0002 and 1.98
fLimit = (((f2/f1)>1.0002) & ((f2/f1)<1.98)) : smooth(0.999);

// stereo output, alternating channels
Chan1 = osc(f1), osc(f3), osc(f5), osc(f7), osc(f9), osc(f11) :> /(6);
Chan2 = osc(f2), osc(f4), osc(f6), osc(f8), osc(f10), osc(f12) :> /(6);

// stereo (with optional sanity checks from output 3-6)
process = Chan1 * fLimit, Chan2 * fLimit, SC1, SC2, SC3, SC4;


