declare name "f1half";
declare author "Alex Chechile";
declare version "The Ear Tone Toolbox v.1.01";
declare copyright "Copyright 2016 Alex Chechile (chechile@ccrma.stanford.edu)";
declare license "GNU GPL (see COPYING.txt)";
declare description "The constrained version of f1half to help keep the f1 & f2 primary tones in proper ratio for producing robust QDT and CDT";

import("music.lib");
import("filter.lib");

// input parameters 
QDT = hslider("QDT",1,1,3000,0.0001);
CDT = hslider("CDT",1,1,2100,0.0001);
f1 = hslider("f1",1,1,5000,0.0001);

// generate f2 with f1 and either the QDT value or the CDT value.  The opposite value must be 1 to work.
f2 = ((QDT+f1)*((QDT>1) & (CDT == 1))) + (((2*f1)-CDT)*((CDT>1) & (QDT == 1)));

// Limit for f2/f1 ratio to stay between 1.009 and 1.98, and keep the value positive
fLimit = (((f2/f1)>1.009) & ((f2/f1)<1.98) & (f2>0)) : smooth(0.999);

// primary tones 
Chan1 = osc(f1) * fLimit;
Chan2 = osc(f2) * fLimit;

// optional sanity check
Chan3 = osc(f2-f1); // QDT
Chan4 = osc((2*f1)-f2); // CDT

process = Chan1,Chan2,Chan3,Chan4;

