declare name "f2half_unlim";
declare author "Alex Chechile";
declare version "The Ear Tone Toolbox v.1.01";
declare copyright "Copyright 2016 Alex Chechile (chechile@ccrma.stanford.edu)";
declare license "GNU GPL (see COPYING.txt)";
declare description "This is the unconstrained version of f2half, but the f2/f1 ratio may exceed usable range for producing QDT and CDT.";

import("music.lib");
import("math.lib"); 
import("filter.lib");

// input parameters 
QDT = hslider("QDT",1,1,15000,0.0001);
CDT = hslider("CDT",1,1,15000,0.0001);
f2 = hslider("f2",1,1,20000,0.0001);

// generate f1 with f2 and either the QDT value or the CDT value.  The opposite value must be 1 to work.
//abs value to keep positive
f1 = fabs(((f2-QDT)*((QDT>1) & (CDT == 1))) + (((CDT+f2)/2)*((CDT>1) & (QDT == 1))));

// shut off oscillator if f1 is 0
fLimit = (f1!=0) : smooth(0.999);

// primary tones
Chan1 = osc(f1) * fLimit;
Chan2 = osc(f2);

// optional sanity check
Chan3 = osc(f2-f1); // QDT
Chan4 = osc((2*f1)-f2); // CDT

process = Chan1,Chan2,Chan3,Chan4;

