declare name "DPSpecS_PT_Mono_ins";
declare author "Alex Chechile";
declare version "The Ear Tone Toolbox v.1.01";
declare copyright "Copyright 2016 Alex Chechile (chechile@ccrma.stanford.edu)";
declare license "GNU GPL (see COPYING.txt)";
declare description "Monophonic MIDI control over primary tone spectrum.  The f0 QDT difference tone is a user defined parameter.  Constrained to help produce robust distortion products.";

import("music.lib");

f0 = hslider("f0",100,1,1150,0.0001); // f0 is the quadratic difference tone f2-f1 value

freq = hslider("freq",1000,1,7000,0.0001); // freq is the f1 first primary tone value, and controlled by MIDI input
gain = hslider("gain",1,0,1,0.0001);
gate = button("gate");

// primary tone spectrum
f2 = f0 + freq;
f3 = 2 * f0 + freq;
f4 = 3 * f0 + freq;
f5 = 4 * f0 + freq;
f6 = 5 * f0 + freq;
f7 = 6 * f0 + freq;
f8 = 7 * f0 + freq;
f9 = 8 * f0 + freq;
f10 = 9 * f0 + freq;
f11 = 10 * f0 + freq;
f12 = 11 * f0 + freq;

// Limit for f2/f1 ratio to stay between 1.0002 and 1.98
fLimit = (((f2/freq)>1.0002) & ((f2/freq)<1.98));

// stereo output, alternating channels
Chan1 = osc(freq), osc(f3), osc(f5), osc(f7), osc(f9), osc(f11) :> /(6);
Chan2 = osc(f2), osc(f4), osc(f6), osc(f8), osc(f10), osc(f12) :> /(6);

// ADSR envelope parameters
attack  = hslider("attack", 0.02,0.01, 1, 0.001); // sec
decay   = hslider("decay",  0.3, 0, 1, 0.001); // sec
sustain = hslider("sustain",0.5, 0, 1, 0.01);  // frac
release = hslider("release",0.2, 0.01, 1, 0.001); // sec

env = gate : adsr(attack,decay,sustain,release);

process = ((Chan1*fLimit)*env*gain), ((Chan2*fLimit)*env*gain);