declare name "DPSpecS_QDT_unlim_Mono_ins";
declare author "Alex Chechile";
declare version "The Ear Tone Toolbox v.1.01";
declare copyright "Copyright 2016 Alex Chechile (chechile@ccrma.stanford.edu)";
declare license "GNU GPL (see COPYING.txt)";
declare description "MIDI control over QDT value (monophonic).  The f1 primary tone is a user defined parameter.  Unconstrained, but the f2/f1 ratio may exceed usable range for producing audible DTs";

import("music.lib");

f1 = hslider("f1",1000,1,7000,0.0001); // f1 is the first primary tone

freq = hslider("freq",100,1,1150,0.0001); // freq is the f0 quadratic difference tone f2-f1 value, and controlled by MIDI input
gain = hslider("gain",1,0,1,0.0001);
gate = button("gate");

// primary tone spectrum
f2 = freq + f1;
f3 = 2 * freq + f1;
f4 = 3 * freq + f1;
f5 = 4 * freq + f1;
f6 = 5 * freq + f1;
f7 = 6 * freq + f1;
f8 = 7 * freq + f1;
f9 = 8 * freq + f1;
f10 = 9 * freq + f1;
f11 = 10 * freq + f1;
f12 = 11 * freq + f1;


// stereo output, alternating channels
Chan1 = osc(f1), osc(f3), osc(f5), osc(f7), osc(f9), osc(f11) :> /(6);
Chan2 = osc(f2), osc(f4), osc(f6), osc(f8), osc(f10), osc(f12) :> /(6);

// ADSR envelope parameters
attack  = hslider("attack", 0.02,0.01, 1, 0.001); // sec
decay   = hslider("decay",  0.3, 0, 1, 0.001); // sec
sustain = hslider("sustain",0.5, 0, 1, 0.01);  // frac
release = hslider("release",0.2, 0.01, 1, 0.001); // sec

env = gate : adsr(attack,decay,sustain,release);

process = (Chan1*env*gain), (Chan2*env*gain);