declare name "f1half_unlim_Mono_ins";
declare author "Alex Chechile";
declare version "The Ear Tone Toolbox v.1.01";
declare copyright "Copyright 2016 Alex Chechile (chechile@ccrma.stanford.edu)";
declare license "GNU GPL (see COPYING.txt)";
declare description "f1half_unlim_Mono_ins evokes the user defined QDT or CDT while also allowing control over the lower primary tone, f1 by MIDI input. One of either the QDT or the CDT values must be set to 1 for the VSTi to work.";

import("music.lib");
import("math.lib");

// input parameters 
QDT = hslider("QDT",880,1,15000,0.0001); 
CDT = hslider("CDT",1,1,15000,0.0001);

freq = hslider("freq",1,1,20000,0.0001); // freq is the f1 acoustic primary tone, and is controlled by MIDI input
gain = hslider("gain",1,0,1,0.0001);
gate = button("gate");

// generate f2 with f1 (freq) and either the QDT value or the CDT value.  The opposite value must be 1 to work.
//abs value to keep positive
f2 = fabs(((QDT+freq)*((QDT>1) & (CDT == 1))) + (((2*freq)-CDT)*((CDT>1) & (QDT == 1))));

// shut off oscillator if f2 is 0
fLimit = (f2!=0);

// primary tones
Chan1 = osc(freq) * fLimit;
Chan2 = osc(f2) * fLimit;

// ADSR envelope parameters
attack  = hslider("attack", 0.02,0.01, 1, 0.001); // sec
decay   = hslider("decay",  0.3, 0, 1, 0.001); // sec
sustain = hslider("sustain",0.5, 0, 1, 0.01);  // frac
release = hslider("release",0.2, 0.01, 1, 0.001); // sec

env = gate : adsr(attack,decay,sustain,release);

process = (Chan1*env*gain), (Chan2*env*gain);