declare name "f2half_Mono_ins";
declare author "Alex Chechile";
declare version "The Ear Tone Toolbox v.1.01";
declare copyright "Copyright 2016 Alex Chechile (chechile@ccrma.stanford.edu)";
declare license "GNU GPL (see COPYING.txt)";
declare description "f2half_Mono_ins evokes the user defined QDT or CDT while also allowing control over the higher primary tone, f2 by MIDI input. One of either the QDT or the CDT values must be set to 1 for the VSTi to work. Constrained.";

import("music.lib");

// input parameters 
QDT = hslider("QDT",880,1,15000,0.0001);
CDT = hslider("CDT",1,1,15000,0.0001);

freq = hslider("freq",1,1,20000,0.0001); // freq is the f2 acoustic primary tone, and is controlled by MIDI input
gain = hslider("gain",1,0,1,0.0001);
gate = button("gate");

// generate f1 with f2 (freq) and either the QDT value or the CDT value.  The opposite value must be 1 to work.
f1 = ((freq-QDT)*((QDT>1) & (CDT == 1))) + (((CDT+freq)/2)*((CDT>1) & (QDT == 1)));

// Limit for f2/f1 ratio to stay between 1.009 and 1.98, and keep the value positive
fLimit = (((freq/f1)>1.009) & ((freq/f1)<1.98) & (f1>0));

// primary tones
Chan1 = osc(f1) * fLimit;
Chan2 = osc(freq) * fLimit;

// ADSR envelope parameters
attack  = hslider("attack", 0.02,0.01, 1, 0.001); // sec
decay   = hslider("decay",  0.3, 0, 1, 0.001); // sec
sustain = hslider("sustain",0.5, 0, 1, 0.01);  // frac
release = hslider("release",0.2, 0.01, 1, 0.001); // sec

env = gate : adsr(attack,decay,sustain,release);

process = (Chan1*env*gain), (Chan2*env*gain);