declare name "DPSpecS_OWL (10 primary tones)";
declare author "Alex Chechile";
declare version "The Ear Tone Toolbox v.1.01";
declare copyright "Copyright 2016 Alex Chechile (chechile@ccrma.stanford.edu)";
declare license "GNU GPL (see COPYING.txt)";
declare description "Generates a stereo spectrum of primary tones based on the f1 primary and the f0 QDT fundamental, which is also the spacing";

import("filter.lib"); // for smooth and tau2pole

// to help with pitch stabilization on the OWL:
// _*_ (the square) changes the knob from logarithmic to linear
// then quantizing the signal by multiplying, turning the value to an int, and then dividing
// then scaling to the desired range, and smoothing the result

// the smooth value is set to OWL parameter E
x = hslider("gliss[OWL:PARAMETER_E]",0.01,0.0,5.0,0.01);

// input parameters: f0 is the quadratic difference tone f2-f1 value, and f0 is the quadratic difference tone f2-f1 value
f0 = hslider("f0[OWL:PARAMETER_A]",0,0,1,0.0001) <:_*_ : *(1000000) : int : /(1000000) : *(1150-1)+(1) : smooth(tau2pole(x));
f1 = hslider("f1[OWL:PARAMETER_B]",0,0,1,0.0001) <:_*_ : *(1000000) : int : /(1000000) : *(7000-40)+(40) : smooth(tau2pole(x));

// primary tone spectrum
f2 = f0 + f1;
f3 = 2 * f0 + f1;
f4 = 3 * f0 + f1;
f5 = 4 * f0 + f1;
f6 = 5 * f0 + f1;
f7 = 6 * f0 + f1;
f8 = 7 * f0 + f1;
f9 = 8 * f0 + f1;
f10 = 9 * f0 + f1;

// Limit for f2/f1 ratio to stay between 1.0002 and 1.98
fLimit = (((f2/f1)>1.0002) & ((f2/f1)<1.98)) : smooth(0.999);

phasor(f) = f/SR : (+,1.0:fmod)~_;

Chan1 = (phasor(f1) * 6.28318530717959 : sin), (phasor(f3) * 6.28318530717959 : sin), (phasor(f5) * 6.28318530717959 : sin), (phasor(f7) * 6.28318530717959 : sin), (phasor(f9) * 6.28318530717959 : sin):> /(5);
Chan2 = (phasor(f2) * 6.28318530717959 : sin), (phasor(f4) * 6.28318530717959 : sin), (phasor(f6) * 6.28318530717959 : sin), (phasor(f8) * 6.28318530717959 : sin), (phasor(f10) * 6.28318530717959 : sin):> /(5);

process = Chan1 * fLimit, Chan2 * fLimit;

