declare name "DiffTone_SC_Stereo_OWL";
declare author "Alex Chechile";
declare version "The Ear Tone Toolbox v.1.01";
declare copyright "Copyright 2016 Alex Chechile (chechile@ccrma.stanford.edu)";
declare license "GNU GPL (see COPYING.txt)";
declare description "Generates f1 and f2 primaries from the user defined QDT and CDT (outs L & R).  This version has an optional sanity check (volume should be down unless testing)";

import("filter.lib"); // for smooth and tau2pole

// to help with pitch stabilization on the OWL:
// _*_ (the square) changes the knob from logarithmic to linear
// then quantizing the signal by multiplying, turning the value to an int, and then dividing
// then scaling to the desired range, and smoothing the result

// the smooth value is set to OWL parameter E
x = hslider("gliss[OWL:PARAMETER_E]",0.01,0.0,5.0,0.01);

// input parameters
QDT = hslider("QDT[OWL:PARAMETER_A]",0,0,1,0.0001) <:_*_ : *(1000000) : int : /(1000000) : *(3000-25)+(25) : smooth(tau2pole(x));
CDT = hslider("CDT[OWL:PARAMETER_B]",0,0,1,0.0001) <:_*_ : *(1000000) : int : /(1000000) : *(2100-55)+(55) : smooth(tau2pole(x));

// volume control for optional sanity check
QDTvol = hslider("QDTvol[OWL:PARAMETER_C]",0,0,1,0.0001) : smooth(tau2pole(0.01));
CDTvol = hslider("CDTvol[OWL:PARAMETER_D]",0,0,1,0.0001) : smooth(tau2pole(0.01));

// primary tones from QDT and CDT values
f1 = CDT + QDT;
f2 = f1 + QDT;

// Sanity Check
QDTsc = (f2 - f1);
CDTsc = ((2*f1)-f2);

phasor(f) = f/SR : (+,1.0:fmod)~_;

// primaries with optional guide tones from outs L and R (sanity check should usually be silent)
Chan1 = (phasor(f1) * 6.28318530717959 : sin), ((phasor(QDTsc) * 6.28318530717959 : sin) : * (QDTvol)) :> /(2);
Chan2 = (phasor(f2) * 6.28318530717959 : sin), ((phasor(CDTsc) * 6.28318530717959 : sin) : * (CDTvol)) :> /(2);

process = Chan1,Chan2;


