declare name "DiffTone_dual_OWL";
declare author "Alex Chechile";
declare version "The Ear Tone Toolbox v.1.01";
declare copyright "Copyright 2016 Alex Chechile (chechile@ccrma.stanford.edu)";
declare license "GNU GPL (see COPYING.txt)";
declare description "DiffTone generates f1 and f2 primary tones from the user defined QDT and CDT.  Voice 1 from out L, and voice 2 from out R.";

import("filter.lib"); // for smooth and tau2pole

// to help with pitch stabilization on the OWL:
// _*_ (the square) changes the knob from logarithmic to linear
// then quantizing the signal by multiplying, turning the value to an int, and then dividing
// then scaling to the desired range, and smoothing the result

// the smooth value is set to OWL parameter E
x = hslider("gliss[OWL:PARAMETER_E]",0.01,0.0,5.0,0.01);

// first voice input parameters (a)
QDTa = hslider("QDT_a[OWL:PARAMETER_A]",0,0,1,0.0001) <:_*_ : *(1000000) : int : /(1000000) : *(3000-25)+(25) : smooth(tau2pole(x));
CDTa = hslider("CDT_a[OWL:PARAMETER_B]",0,0,1,0.0001) <:_*_ : *(1000000) : int : /(1000000) : *(2100-55)+(55) : smooth(tau2pole(x));

// second voice input parameters (b)
QDTb = hslider("QDT_b[OWL:PARAMETER_C]",0,0,1,0.0001) <:_*_ : *(1000000) : int : /(1000000) : *(3000-25)+(25) : smooth(tau2pole(x));
CDTb = hslider("CDT_b[OWL:PARAMETER_D]",0,0,1,0.0001) <:_*_ : *(1000000) : int : /(1000000) : *(2100-55)+(55) : smooth(tau2pole(x));

// first voice primaries
f1 = CDTa + QDTa;
f2 = f1 + QDTa;

// second voice primaries
f3 = CDTb + QDTb;
f4 = f3 + QDTb;


phasor(f) = f/SR : (+,1.0:fmod)~_;

// first voice
Osc1 = phasor(f1) * 6.28318530717959 : sin;
Osc2 = phasor(f2) * 6.28318530717959 : sin;

// second voice
Osc3 = phasor(f3) * 6.28318530717959 : sin;
Osc4 = phasor(f4) * 6.28318530717959 : sin;

Voice1 = (Osc1+Osc2)*0.5;
Voice2 = (Osc3+Osc4)*0.5;

process = Voice1,Voice2;


