declare name "f1ratio_SC_Stereo_OWL";
declare author "Alex Chechile";
declare version "The Ear Tone Toolbox v.1.01";
declare copyright "Copyright 2016 Alex Chechile (chechile@ccrma.stanford.edu)";
declare license "GNU GPL (see COPYING.txt)";
declare description "Provides the user control over the f2/f1 primary tone ratio for producing QDT and CDT (outs L&R).  This version has an optional sanity check (volume should be down unless testing)";

import("filter.lib"); // for smooth and tau2pole

// to help with pitch stabilization on the OWL:
// _*_ (the square) changes the knob from logarithmic to linear
// then quantizing the signal by multiplying, turning the value to an int, and then dividing
// then scaling to the desired range, and smoothing the result

// the smooth value is set to OWL parameter E
x = hslider("gliss[OWL:PARAMETER_E]",0.01,0.0,5.0,0.01);

// input parameters
f1 = hslider("f1[OWL:PARAMETER_A]",0,0,1,0.0001) <:_*_ : *(1000000) : int : /(1000000) : *(5000-40)+(40) : smooth(tau2pole(x));
ratio = hslider("ratio[OWL:PARAMETER_B]",0,0,1,0.0001) <:_*_ : *(1000000) : int : /(1000000) : *(1.98-1.009)+(1.009) : smooth(tau2pole(x));

// volume control for optional sanity check from outlet R
QDTvol = hslider("QDTvol[OWL:PARAMETER_C]",0,0,1,0.0001) : smooth(tau2pole(0.01));
CDTvol = hslider("CDTvol[OWL:PARAMETER_D]",0,0,1,0.0001) : smooth(tau2pole(0.01));

// f2 calculated from f1 and ratio
f2 = f1*ratio;

// calculate difference tones for sanity check
QDT = f2-f1;
CDT = ((2*f1)-f2);

phasor(f) = f/SR : (+,1.0:fmod)~_;

// primaries with optional guide tones from outs L and R (sanity check should usually be silent)
Chan1 = (phasor(f1) * 6.28318530717959 : sin), ((phasor(QDT) * 6.28318530717959 : sin) : * (QDTvol)) :> /(2);
Chan2 = (phasor(f2) * 6.28318530717959 : sin), ((phasor(CDT) * 6.28318530717959 : sin) : * (CDTvol)) :> /(2);

process = Chan1,Chan2;


