declare name "f1ratio_dual_OWL";
declare author "Alex Chechile";
declare version "The Ear Tone Toolbox v.1.01";
declare copyright "Copyright 2016 Alex Chechile (chechile@ccrma.stanford.edu)";
declare license "GNU GPL (see COPYING.txt)";
declare description "Provides the user control over the f2/f1 primary tone ratio for producing QDT and CDT. Voice 1 from out L, and voice 2 from out R.";

import("filter.lib"); // for smooth and tau2pole

// to help with pitch stabilization on the OWL:
// _*_ (the square) changes the knob from logarithmic to linear
// then quantizing the signal by multiplying, turning the value to an int, and then dividing
// then scaling to the desired range, and smoothing the result

// the smooth value is set to OWL parameter E
x = hslider("gliss[OWL:PARAMETER_E]",0.01,0.0,5.0,0.01);

// first voice input parameters (a)
f1a = hslider("f1_a[OWL:PARAMETER_A]",0,0,1,0.0001) <:_*_ : *(1000000) : int : /(1000000) : *(5000-40)+(40) : smooth(tau2pole(x));
ratioa = hslider("ratio_a[OWL:PARAMETER_B]",0,0,1,0.0001) <:_*_ : *(1000000) : int : /(1000000) : *(1.98-1.009)+(1.009) : smooth(tau2pole(x));

// second voice input parameters (b)
f1b = hslider("f1_b[OWL:PARAMETER_C]",0,0,1,0.0001) <:_*_ : *(1000000) : int : /(1000000) : *(5000-40)+(40) : smooth(tau2pole(x));
ratiob = hslider("ratio_b[OWL:PARAMETER_D]",0,0,1,0.0001) <:_*_ : *(1000000) : int : /(1000000) : *(1.98-1.009)+(1.009) : smooth(tau2pole(x));

// first voice f2 calculated based on ratio
f2a = f1a*ratioa;

// second voice f2 calculated based on ratio
f2b = f1b*ratiob;


phasor(f) = f/SR : (+,1.0:fmod)~_;

// first voice
Osc1 = phasor(f1a) * 6.28318530717959 : sin;
Osc2 = phasor(f2a) * 6.28318530717959 : sin;

// second voice
Osc3 = phasor(f1b) * 6.28318530717959 : sin;
Osc4 = phasor(f2b) * 6.28318530717959 : sin;

Voice1 = (Osc1+Osc2)*0.5;
Voice2 = (Osc3+Osc4)*0.5;

process = Voice1,Voice2;
