declare name "f2half_OWL";
declare author "Alex Chechile";
declare version "The Ear Tone Toolbox v.1.01";
declare copyright "Copyright 2016 Alex Chechile (chechile@ccrma.stanford.edu)";
declare license "GNU GPL (see COPYING.txt)";
declare description "The constrained version of f2half to help keep the f1 & f2 primary tones in proper ratio for producing robust QDT and CDT";

import("filter.lib"); // for smooth and tau2pole

// to help with pitch stabilization on the OWL:
// _*_ (the square) changes the knob from logarithmic to linear
// then quantizing the signal by multiplying, turning the value to an int, and then dividing
// then scaling to the desired range, and smoothing the result

// the smooth value is set to OWL parameter E
x = hslider("gliss[OWL:PARAMETER_E]",0.01,0.0,5.0,0.01);

// input parameters 
f2 = hslider("f2[OWL:PARAMETER_A]",0.1,0,1,0.0001) <:_*_ : *(1000000) : int : /(1000000) : *(5000-40)+(40) : smooth(tau2pole(x));
QDT = hslider("QDT[OWL:PARAMETER_B]",0.1,0,1,0.0001) <:_*_ : *(1000000) : int : /(1000000) : *(3000-1)+(1) : smooth(tau2pole(x));
CDT = hslider("CDT[OWL:PARAMETER_C]",0,0,1,0.0001) <:_*_ : *(1000000) : int : /(1000000) : *(2100-1)+(1) : smooth(tau2pole(x));

// generate f1 with f2 and either the QDT value or the CDT value.  The opposite value must be 1 to work.
f1 = ((f2-QDT)*((QDT>1) & (CDT == 1))) + (((CDT+f2)/2)*((CDT>1) & (QDT == 1)));

// Limit for f2/f1 ratio to stay between 1.009 and 1.98, and keep it positive
fLimit = (((f2/f1)>1.009) & ((f2/f1)<1.98) & (f1>0)) : smooth(0.999);

phasor(f) = f/SR : (+,1.0:fmod)~_;

Chan1 = (phasor(f1) * 6.28318530717959 : sin) * fLimit;
Chan2 = (phasor(f2) * 6.28318530717959 : sin) * fLimit;

process = Chan1,Chan2;

